@@ -1,5 +1,6 @@
 #coding: utf-8
 import os
+import random
 
 from django.db import models
 from django.contrib.auth.models import User
@@ -10,6 +11,7 @@ from django.contrib.contenttypes.generic import GenericTabularInline, GenericFor
 from django.utils.translation import ugettext_lazy as _
 
 from generic_utils.injector import GenericInjector
+from generic_images.signals import image_saved, image_deleted
 
 
 class ReplaceOldImageModel(models.Model):
@@ -85,6 +87,12 @@ class AttachedImage(ReplaceOldImageModel):
     def _get_next_pk(self):
         max_pk = AttachedImage.objects.aggregate(max_pk=Max('pk'))['max_pk'] or 0
         return max_pk+1
+
+
+    def get_file_name(self, filename):
+#        alphabet = "1234567890abcdefghijklmnopqrstuvwxyz"        
+#        return ''.join([random.choice(alphabet) for i in xrange(16)]) # 1e25 variants
+        return str(self._get_next_pk())
     
         
     def get_upload_path(self, filename):
@@ -93,11 +101,10 @@ class AttachedImage(ReplaceOldImageModel):
             or "/media/images/common/<image.id>.<ext>" if user is not set.
             image.id is predicted as it is unknown at this stage.
         '''        
-        predicted_pk = self._get_next_pk()        
-        user_folder = str(self.user.pk) if self.user else 'common'
+        user_folder = str(self.user.pk) if self.user else 'common'        
         
         root, ext = os.path.splitext(filename)
-        return os.path.join('media', 'images', user_folder, str(predicted_pk) + ext)    
+        return os.path.join('media', 'images', user_folder, self.get_file_name(filename) + ext)    
     
     
     def save(self, *args, **kwargs):
@@ -107,8 +114,14 @@ class AttachedImage(ReplaceOldImageModel):
             related_images.update(is_main=False)
         if not self.pk:
             self.order = self._get_next_pk()
-        super(AttachedImage, self).save(*args, **kwargs)        
-    
+        super(AttachedImage, self).save(*args, **kwargs)         
+        image_saved.send(sender = self.content_type.model_class(), instance = self)
+        
+        
+    def delete(self, *args, **kwargs):
+        image_deleted.send(sender = self.content_type.model_class(), instance = self)
+        super(AttachedImage, self).delete(*args, **kwargs)            
+        
         
     def __unicode__(self):
         try:
